pub struct ColorfulTheme {Show 20 fields
pub defaults_style: Style,
pub prompt_style: Style,
pub prompt_prefix: StyledObject<String>,
pub prompt_suffix: StyledObject<String>,
pub success_prefix: StyledObject<String>,
pub success_suffix: StyledObject<String>,
pub error_prefix: StyledObject<String>,
pub error_style: Style,
pub hint_style: Style,
pub values_style: Style,
pub active_item_style: Style,
pub inactive_item_style: Style,
pub active_item_prefix: StyledObject<String>,
pub inactive_item_prefix: StyledObject<String>,
pub checked_item_prefix: StyledObject<String>,
pub unchecked_item_prefix: StyledObject<String>,
pub picked_item_prefix: StyledObject<String>,
pub unpicked_item_prefix: StyledObject<String>,
pub fuzzy_cursor_style: Style,
pub fuzzy_match_highlight_style: Style,
}Expand description
A colorful theme
Fields
defaults_style: StyleThe style for default values
prompt_style: StyleThe style for prompt
prompt_prefix: StyledObject<String>Prompt prefix value and style
prompt_suffix: StyledObject<String>Prompt suffix value and style
success_prefix: StyledObject<String>Prompt on success prefix value and style
success_suffix: StyledObject<String>Prompt on success suffix value and style
error_prefix: StyledObject<String>Error prefix value and style
error_style: StyleThe style for error message
hint_style: StyleThe style for hints
values_style: StyleThe style for values on prompt success
active_item_style: StyleThe style for active items
inactive_item_style: StyleThe style for inactive items
active_item_prefix: StyledObject<String>Active item in select prefix value and style
inactive_item_prefix: StyledObject<String>Inctive item in select prefix value and style
checked_item_prefix: StyledObject<String>Checked item in multi select prefix value and style
unchecked_item_prefix: StyledObject<String>Unchecked item in multi select prefix value and style
picked_item_prefix: StyledObject<String>Picked item in sort prefix value and style
unpicked_item_prefix: StyledObject<String>Unpicked item in sort prefix value and style
fuzzy_cursor_style: Stylefuzzy-select only.Formats the cursor for a fuzzy select prompt
fuzzy_match_highlight_style: Stylefuzzy-select only.Trait Implementations
Sourceimpl Default for ColorfulTheme
impl Default for ColorfulTheme
Sourcefn default() -> ColorfulTheme
fn default() -> ColorfulTheme
Sourceimpl Theme for ColorfulTheme
impl Theme for ColorfulTheme
Sourcefn format_input_prompt(
&self,
f: &mut dyn Write,
prompt: &str,
default: Option<&str>,
) -> Result
fn format_input_prompt( &self, f: &mut dyn Write, prompt: &str, default: Option<&str>, ) -> Result
Formats an input prompt.
Sourcefn format_confirm_prompt(
&self,
f: &mut dyn Write,
prompt: &str,
default: Option<bool>,
) -> Result
fn format_confirm_prompt( &self, f: &mut dyn Write, prompt: &str, default: Option<bool>, ) -> Result
Formats a confirm prompt.
Sourcefn format_confirm_prompt_selection(
&self,
f: &mut dyn Write,
prompt: &str,
selection: Option<bool>,
) -> Result
fn format_confirm_prompt_selection( &self, f: &mut dyn Write, prompt: &str, selection: Option<bool>, ) -> Result
Formats a confirm prompt after selection.
Sourcefn format_input_prompt_selection(
&self,
f: &mut dyn Write,
prompt: &str,
sel: &str,
) -> Result
fn format_input_prompt_selection( &self, f: &mut dyn Write, prompt: &str, sel: &str, ) -> Result
Formats an input prompt after selection.
Sourcefn format_password_prompt_selection(
&self,
f: &mut dyn Write,
prompt: &str,
) -> Result
Available on crate feature password only.
fn format_password_prompt_selection( &self, f: &mut dyn Write, prompt: &str, ) -> Result
password only.Formats a password prompt after selection.
Sourcefn format_multi_select_prompt_selection(
&self,
f: &mut dyn Write,
prompt: &str,
selections: &[&str],
) -> Result
fn format_multi_select_prompt_selection( &self, f: &mut dyn Write, prompt: &str, selections: &[&str], ) -> Result
Formats a multi select prompt after selection.
Sourcefn format_select_prompt_item(
&self,
f: &mut dyn Write,
text: &str,
active: bool,
) -> Result
fn format_select_prompt_item( &self, f: &mut dyn Write, text: &str, active: bool, ) -> Result
Formats a select prompt item.
Sourcefn format_multi_select_prompt_item(
&self,
f: &mut dyn Write,
text: &str,
checked: bool,
active: bool,
) -> Result
fn format_multi_select_prompt_item( &self, f: &mut dyn Write, text: &str, checked: bool, active: bool, ) -> Result
Formats a multi select prompt item.
Sourcefn format_sort_prompt_item(
&self,
f: &mut dyn Write,
text: &str,
picked: bool,
active: bool,
) -> Result
fn format_sort_prompt_item( &self, f: &mut dyn Write, text: &str, picked: bool, active: bool, ) -> Result
Formats a sort prompt item.
Sourcefn format_fuzzy_select_prompt_item(
&self,
f: &mut dyn Write,
text: &str,
active: bool,
highlight_matches: bool,
matcher: &SkimMatcherV2,
search_term: &str,
) -> Result
Available on crate feature fuzzy-select only.
fn format_fuzzy_select_prompt_item( &self, f: &mut dyn Write, text: &str, active: bool, highlight_matches: bool, matcher: &SkimMatcherV2, search_term: &str, ) -> Result
fuzzy-select only.Formats a fuzzy select prompt item.
Sourcefn format_fuzzy_select_prompt(
&self,
f: &mut dyn Write,
prompt: &str,
search_term: &str,
bytes_pos: usize,
) -> Result
Available on crate feature fuzzy-select only.
fn format_fuzzy_select_prompt( &self, f: &mut dyn Write, prompt: &str, search_term: &str, bytes_pos: usize, ) -> Result
fuzzy-select only.Formats a fuzzy-selectprompt after selection.
Sourcefn format_password_prompt(&self, f: &mut dyn Write, prompt: &str) -> Result
fn format_password_prompt(&self, f: &mut dyn Write, prompt: &str) -> Result
password only.